@@ -64,6 +64,7 @@ ROOM_TYPES = [
 
 FAN_MODEL_TYPES = {
     "FAN,HAIKU,SENSEME": "Haiku Fan",
+    "FAN,HAIKU,HSERIES": "Haiku Fan",  # H Series is now called plain Haiku
     "FAN,LSERIES": "Haiku L Fan",
 }
 
@@ -327,9 +328,13 @@ class SensemeFan:
         return FAN_MODEL_TYPES.get(self._model.upper(), self._model.upper())
 
     @classmethod
-    def models(cls):
+    def models(cls) -> list:
         """Return list of possible model names."""
-        return list(FAN_MODEL_TYPES.values())
+        no_duplicates = []
+        for model_name in FAN_MODEL_TYPES.values():
+            if model_name not in no_duplicates:
+                no_duplicates.append(model_name)
+        return no_duplicates
 
     @property
     def fw_version(self) -> str:
@@ -799,6 +804,14 @@ class SensemeFan:
                     "%s: Updater task error\n%s", self._name, traceback.format_exc()
                 )
                 await asyncio.sleep(self.refresh_minutes * 60 + random.uniform(-10, 10))
+            except Exception:
+                _LOGGER.error(
+                    "%s: Unhandled updater task error\n%s",
+                    self._name,
+                    traceback.format_exc(),
+                )
+                await asyncio.sleep(10)
+                raise
         _LOGGER.error("%s: Updater task ended", self._name)
 
     async def _listener(self):
@@ -915,6 +928,11 @@ class SensemeFan:
                 )
                 self._error_count += 1
                 await asyncio.sleep(1)
+            except Exception:
+                _LOGGER.error(
+                    "%s: Listener task error\n%s", self._name, traceback.format_exc()
+                )
+                raise
         _LOGGER.error("%s: Listener task ended", self._name)
 
     def start(self):
